[dests] Fix hipTestClock, hipTestNew & hipTestGlobalVariable tests for nvcc
nvcc does not support global kernels in struct/class Change-Id: I2d7297e0c3725564215e20dbdd31c0bb8d7a07de
This commit is contained in:
@@ -33,8 +33,6 @@ THE SOFTWARE.
|
||||
#define LEN 512
|
||||
#define SIZE 2048
|
||||
|
||||
struct TestClock {
|
||||
|
||||
static __global__ void kernel1(int* Ad) {
|
||||
int tid = threadIdx.x + blockIdx.x * blockDim.x;
|
||||
Ad[tid] = clock() + clock64() + __clock() + __clock64();
|
||||
@@ -61,9 +59,8 @@ struct TestClock {
|
||||
assert(0 != A[i]);
|
||||
}
|
||||
}
|
||||
};
|
||||
|
||||
int main() {
|
||||
TestClock().run();
|
||||
run();
|
||||
passed();
|
||||
}
|
||||
|
||||
@@ -33,7 +33,6 @@ THE SOFTWARE.
|
||||
#define LEN 512
|
||||
#define SIZE 2048
|
||||
|
||||
struct TestPlacementNew {
|
||||
class A {
|
||||
public:
|
||||
__device__ A() {
|
||||
@@ -63,9 +62,8 @@ struct TestPlacementNew {
|
||||
assert(i == A[i]);
|
||||
}
|
||||
}
|
||||
};
|
||||
|
||||
int main() {
|
||||
TestPlacementNew().run();
|
||||
run();
|
||||
passed();
|
||||
}
|
||||
|
||||
@@ -33,15 +33,14 @@ THE SOFTWARE.
|
||||
#define LEN 512
|
||||
#define SIZE 2048
|
||||
|
||||
struct TestConstantGlobalVar {
|
||||
static __constant__ int ConstantGlobalVar;
|
||||
__constant__ int ConstantGlobalVar = 123;
|
||||
|
||||
static __global__ void kernel(int* Ad) {
|
||||
int tid = threadIdx.x + blockIdx.x * blockDim.x;
|
||||
Ad[tid] = ConstantGlobalVar;
|
||||
}
|
||||
|
||||
void run() {
|
||||
void runTestConstantGlobalVar() {
|
||||
int *A, *Ad;
|
||||
A = new int[LEN];
|
||||
for (unsigned i = 0; i < LEN; i++) {
|
||||
@@ -56,11 +55,8 @@ struct TestConstantGlobalVar {
|
||||
assert(123 == A[i]);
|
||||
}
|
||||
}
|
||||
};
|
||||
__constant__ int TestConstantGlobalVar::ConstantGlobalVar = 123;
|
||||
|
||||
struct TestGlobalArray {
|
||||
static __device__ int GlobalArray[LEN];
|
||||
__device__ int GlobalArray[LEN];
|
||||
|
||||
static __global__ void kernelWrite() {
|
||||
int tid = threadIdx.x + blockIdx.x * blockDim.x;
|
||||
@@ -71,7 +67,7 @@ struct TestGlobalArray {
|
||||
Ad[tid] = GlobalArray[tid];
|
||||
}
|
||||
|
||||
void run() {
|
||||
void runTestGlobalArray() {
|
||||
int *A, *Ad;
|
||||
A = new int[LEN];
|
||||
for (unsigned i = 0; i < LEN; i++) {
|
||||
@@ -87,11 +83,9 @@ struct TestGlobalArray {
|
||||
assert(i == A[i]);
|
||||
}
|
||||
}
|
||||
};
|
||||
__device__ int TestGlobalArray::GlobalArray[LEN];
|
||||
|
||||
int main() {
|
||||
TestConstantGlobalVar().run();
|
||||
TestGlobalArray().run();
|
||||
runTestConstantGlobalVar();
|
||||
runTestGlobalArray();
|
||||
passed();
|
||||
}
|
||||
|
||||
Reference in New Issue
Block a user